<?php 
$translations = array(
	'General_Locale' => 'sv_SE.UTF-8',
	'General_TranslatorName' => 'Fredrik Astrom',
	'General_TranslatorEmail' => 'fredrik@lagun.se',
	'General_EnglishLanguageName' => 'Swedish',
	'General_OriginalLanguageName' => 'Svenska',
	'General_HelloUser' => 'Hej %s!',
	'General_OpenSourceWebAnalytics' => 'Webbanalys med &ouml;ppen k&auml;llkod',
	'General_YourDashboard' => 'Din kontrollpanel',
	'General_API' => 'API',
	'General_Widgets' => 'Widgets',
	'General_Settings' => 'Inst&auml;llningar',
	'General_GiveUsYourFeedback' => 'Ge oss din &aring;sikt',
	'General_Unknown' => 'Ok&auml;nt',
	'General_Required' => '%s kr&auml;vs',
	'General_Error' => 'Fel',
	'General_Warning' => 'Varning',
	'General_BackToHomepage' => 'Tillbaka till Piwik\'s hemsida',
	'General_Yes' => 'Ja',
	'General_No' => 'Nej',
	'General_Delete' => 'Ta bort',
	'General_Edit' => '&Auml;ndra',
	'General_Ok' => 'Ok',
	'General_Close' => 'St&auml;ng',
	'General_Logout' => 'Logga ut',
	'General_Done' => 'Klar',
	'General_LoadingData' => 'Laddar data...',
	'General_Loading' => 'Laddar...',
	'General_ErrorRequest' => 'Oops&hellip; ett problem p&aring;tr&auml;ffades under f&ouml;rfr&aring;gningen, var v&auml;nlig f&ouml;rs&ouml;k igen.',
	'General_Next' => 'N&auml;sta',
	'General_Previous' => 'F&ouml;reg&aring;ende',
	'General_Search' => 'S&ouml;k',
	'General_Others' => 'Andra',
	'General_Table' => 'Tabell',
	'General_Piechart' => 'Cirkeldiagram',
	'General_TagCloud' => 'Taggmoln',
	'General_VBarGraph' => 'Stapeldiagram',
	'General_Export' => 'Exportera',
	'General_ExportAsImage' => 'Exportera som bild',
	'General_SaveImageOnYourComputer' => 'F&ouml;r att spara bilden till datorn, h&ouml;gerklicka p&aring; bilden och v&auml;lj "Spara bild som..."',
	'General_Refresh' => 'Uppdatera sidan',
	'General_Visitors' => 'Bes&ouml;kare',
	'General_ColumnNbUniqVisitors' => 'Unika bes&ouml;kare',
	'General_ColumnNbVisits' => 'Bes&ouml;k',
	'General_ColumnNbActions' => 'H&auml;ndelser',
	'General_ColumnMaxActions' => 'Maximalt antal h&auml;ndelser i ett bes&ouml;k',
	'General_ColumnSumVisitLength' => 'Total tid spenderad av bes&ouml;karna (sekunder)',
	'General_ColumnLabel' => 'Etikett',
	'General_ColumnActionsPerVisit' => 'H&auml;ndelser per bes&ouml;k',
	'General_ColumnAvgTimeOnSite' => 'Tid p&aring; webbplats',
	'General_ColumnBounceRate' => 'Avvisningsfrekvens',
	'General_ColumnPageviews' => 'Sidvisningar',
	'General_ColumnUniquePageviews' => 'Unika sidvisningar',
	'General_ColumnValuePerVisit' => 'V&auml;rde per bes&ouml;k',
	'General_ColumnVisitsWithConversions' => 'Bes&ouml;k med konverteringar',
	'General_Save' => 'Spara',
	'General_Website' => 'Webbplats',
	'General_NoDataForGraph' => 'Ingen data f&ouml;r den h&auml;r grafen',
	'General_NoDataForTagCloud' => 'Ingen data f&ouml;r taggmolnet',
	'General_DisplayNormalTable' => 'Visa normal tabell',
	'General_DisplayMoreData' => 'Visa mer data',
	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s &auml;r ett samarbetsprojekt och fortfarande i betastadiet. %s V&auml;nligen %s kontakta oss%s om du vill hj&auml;lpa till!',
	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Du ser just nu ett demo av %s; %sladda ner%s den fullst&auml;ndiga versionen! Kolla in %s',
	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s finns tillg&auml;ngligt. %s Var v&auml;nlig uppdatera! %s (se %s &auml;ndringar%s).',
	'General_BackToPiwik' => 'Tillbaka till Piwik',
	'General_ShortMonth_1' => "Jan",
	'General_ShortMonth_2' => "Feb",
	'General_ShortMonth_3' => "Mar",
	'General_ShortMonth_4' => "Apr",
	'General_ShortMonth_5' => "Maj",
	'General_ShortMonth_6' => "Jun",
	'General_ShortMonth_7' => "Jul",
	'General_ShortMonth_8' => "Aug",
	'General_ShortMonth_9' => "Sep",
	'General_ShortMonth_10' => "Okt",
	'General_ShortMonth_11' => "Nov",
	'General_ShortMonth_12' => "Dec",
	'General_LongMonth_1' => "Januari",
	'General_LongMonth_2' => "Februari",
	'General_LongMonth_3' => "Mars",
	'General_LongMonth_4' => "April",
	'General_LongMonth_5' => "Maj",
	'General_LongMonth_6' => "Juni",
	'General_LongMonth_7' => "Juli",
	'General_LongMonth_8' => "Augusti",
	'General_LongMonth_9' => "September",
	'General_LongMonth_10' => "Oktober",
	'General_LongMonth_11' => "November",
	'General_LongMonth_12' => "December",
	'General_ShortDay_1' => "M&aring;n",
	'General_ShortDay_2' => "Tis",
	'General_ShortDay_3' => "Ons",
	'General_ShortDay_4' => "Tors",
	'General_ShortDay_5' => "Fre",
	'General_ShortDay_6' => "L&ouml;r",
	'General_ShortDay_7' => "S&ouml;n",
	'General_LongDay_1' => "M&aring;ndag",
	'General_LongDay_2' => "Tisdag",
	'General_LongDay_3' => "Onsdag",
	'General_LongDay_4' => "Torsdag",
	'General_LongDay_5' => "Fredag",
	'General_LongDay_6' => "L&ouml;rdag",
	'General_LongDay_7' => "S&ouml;ndag",
	'CorePluginsAdmin_Plugins' => 'Plugins',
	'CorePluginsAdmin_PluginsManagement' => 'Plugins Management',
	'CorePluginsAdmin_MainDescription' => 'Till&auml;gg ut&ouml;kar Piwik\'s funktioner. N&auml;r ett till&auml;gg &auml;r installerat kan du aktivera eller avaktivera det h&auml;r.',
	'CorePluginsAdmin_Plugin' => 'Till&auml;gg',
	'CorePluginsAdmin_Version' => 'Version',
	'CorePluginsAdmin_Description' => 'Beskrivning',
	'CorePluginsAdmin_Status' => 'Status',
	'CorePluginsAdmin_Action' => '&Aring;tg&auml;rd',
	'CorePluginsAdmin_PluginHomepage' => 'Till&auml;ggets hemsida',
	'CorePluginsAdmin_Activated' => 'Aktiverat',
	'CorePluginsAdmin_Active' => 'Aktiv',
	'CorePluginsAdmin_Inactive' => 'Inaktivt',
	'CorePluginsAdmin_ActivatedHelp' => 'Till&auml;gget kan inte avaktiveras',
	'CorePluginsAdmin_Deactivate' => 'Avaktivera',
	'CorePluginsAdmin_Activate' => 'Aktivera',
	'CorePluginsAdmin_MenuPlugins' => 'Till&auml;gg',	
	'API_QuickDocumentation' => '<h2>Snabbdokumentation f&ouml;r API</h2><p> Om du inte har data f&ouml;r \'i dag\' kan du f&ouml;rst <a href=\'misc/generateVisits.php\' target=_blank> generera lite data</a> med bes&ouml;ksgeneratorn.</p><p>Du kan prova olika format som finns tillg&auml;ngliga f&ouml;r varje metod. Det &auml;r mycket enkelt att extrahera den data du vill ha fr&aring;n piwik!</p><p><b>F&ouml;r mer information, ta en titt p&aring; den <a href=\'http://dev.piwik.org/trac/wiki/API\'>officiell API-dokumentationen</a> eller <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Referensen</a>.</b></p><h2>Anv&auml;ndarverifiering</h2><p>Om du tex vill <b>k&ouml;ra ditt skript i en crontab, eller liknande,</b> m&aring;ste du l&auml;gga till parametern <code><u>&token_auth=%s</u></code> till API-beg&auml;ran som kr&auml;ver autentisering.</p><p>Detta token_auth &auml;r lika hemligt som inloggning och l&ouml;senord, <b>sprid aldrig det!</ p>',
	'API_LoadedAPIs' => '%s APIs laddades utan problem',
	'CoreHome_NoPrivileges' => 'Du &auml;r inloggad som \'%s\' men det ser inte ut som att du har n&aring;gra r&auml;ttigheter inst&auml;llda i Piwik.<br />Be din Piwik-admin att ge dig r&auml;ttigheten att visa en webbplats.',
	'CoreHome_JavascriptDisabled' => 'JavaScript m&aring;ste vara till&aring;tet f&ouml;r att kunna anv&auml;nda Piwik i standardl&auml;ge.<br />Det ser ut som att JavaScript antingen &auml;r avaktiverat eller inte st&ouml;ds av din webbl&auml;sare.<br /> F&ouml;r att anv&auml;nda standardl&auml;get, aktivera JavaScript i din webbl&auml;sare och g&ouml;r ett %s1nytt f&ouml;rs&ouml;k%s2.<br />',
	'CoreHome_TableNoData' => 'Ingen data f&ouml;r den h&auml;r tabellen',
	'CoreHome_CategoryNoData' => 'Ingen data i den h&auml;r kategorin. F&ouml;rs&ouml;k att "visa all data"',
	'CoreHome_ShowJSCode' => 'Visa javascript-koden att l&auml;gga till p&aring; webbplatsen',
	'CoreHome_IncludeAllPopulation_js' => 'Visa all data',
	'CoreHome_ExcludeLowPopulation_js' => 'D&ouml;lj enstaka data',
	'CoreHome_PageOf_js' => '%s av %s',
	'CoreHome_Loading_js' => 'Laddar...',
	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
	'CoreHome_PeriodDay' => 'Dag',
	'CoreHome_PeriodWeek' => 'Vecka',
	'CoreHome_PeriodMonth' => 'M&aring;nad',
	'CoreHome_PeriodYear' => '&Aring;r',
	'CoreHome_PeriodDays' => 'dagar',
	'CoreHome_PeriodWeeks' => 'veckor',
	'CoreHome_PeriodMonths' => 'm&aring;nader',
	'CoreHome_PeriodYears' => '&aring;r',
	'CoreHome_DaySu_js' => 'Sö',
	'CoreHome_DayMo_js' => 'Må',
	'CoreHome_DayTu_js' => 'Ti',
	'CoreHome_DayWe_js' => 'On',
	'CoreHome_DayTh_js' => 'To',
	'CoreHome_DayFr_js' => 'Fr',
	'CoreHome_DaySa_js' => 'Lö',
	'CoreHome_ShortDay_1_js' => 'Sön',
	'CoreHome_ShortDay_2_js' => 'Mån',
	'CoreHome_ShortDay_3_js' => 'Tis',
	'CoreHome_ShortDay_4_js' => 'Ons',
	'CoreHome_ShortDay_5_js' => 'Tor',
	'CoreHome_ShortDay_6_js' => 'Fre',
	'CoreHome_ShortDay_7_js' => 'Lör',
	'CoreHome_LongDay_1_js' => 'Söndag',
	'CoreHome_LongDay_2_js' => 'Måndag',
	'CoreHome_LongDay_3_js' => 'Tisdag',
	'CoreHome_LongDay_4_js' => 'Onsdag',
	'CoreHome_LongDay_5_js' => 'Torsdag',
	'CoreHome_LongDay_6_js' => 'Fredag',
	'CoreHome_LongDay_7_js' => 'Lördag',
	'CoreHome_ShortMonth_1_js' => 'Jan',
	'CoreHome_ShortMonth_2_js' => 'Feb',
	'CoreHome_ShortMonth_3_js' => 'Mar',
	'CoreHome_ShortMonth_4_js' => 'Apr',
	'CoreHome_ShortMonth_5_js' => 'Maj',
	'CoreHome_ShortMonth_6_js' => 'Jun',
	'CoreHome_ShortMonth_7_js' => 'Jul',
	'CoreHome_ShortMonth_8_js' => 'Aug',
	'CoreHome_ShortMonth_9_js' => 'Sep',
	'CoreHome_ShortMonth_10_js' => 'Okt',
	'CoreHome_ShortMonth_11_js' => 'Nov',
	'CoreHome_ShortMonth_12_js' => 'Dec',
	'CoreHome_MonthJanuary_js' => 'Januari',
	'CoreHome_MonthFebruary_js' => 'Februari',
	'CoreHome_MonthMarch_js' => 'Mars',
	'CoreHome_MonthApril_js' => 'April',
	'CoreHome_MonthMay_js' => 'Maj',
	'CoreHome_MonthJune_js' => 'Juni',
	'CoreHome_MonthJuly_js' => 'Juli',
	'CoreHome_MonthAugust_js' => 'Augusti',
	'CoreHome_MonthSeptember_js' => 'September',
	'CoreHome_MonthOctober_js' => 'Oktober',
	'CoreHome_MonthNovember_js' => 'November',
	'CoreHome_MonthDecember_js' => 'December',
	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; uppdatering',
	'CoreUpdater_DatabaseUpgradeRequired' => 'Uppgradering av databasen kr&auml;vs',
	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Din Piwik-databas &auml;r utdaterad och m&aring;ste uppgraderas innan du kan forts&auml;tta.',
	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik\'s databas kommer uppgraderas fr&aring;n version %%s till den nya versionen %s.',
	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'F&ouml;ljande till&auml;gg kommer att uppgraderas: %s.',
	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Uppgraderingsprocessen kan ta ett tag, var v&auml;nlig v&auml;nta.',
	'CoreUpdater_UpgradePiwik' => 'Uppdatera Piwik',
	'CoreUpdater_HelpMessageContent' => 'Titta i %s Piwik FAQ %s som har tagit upp dom vanligaste felen under uppgraderingar. %s Fr&aring;ga din systemadministrat&ouml;r  - som kanske kan hj&auml;lpa dig med problemen som troligast &auml;r relaterade till dina server eller MySQL-inst&auml;llningar.',
	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritiskt fel under uppgraderingsprocessen:',
	'CoreUpdater_HelpMessageIntroductionWhenError' => 'H&auml;r ovanf&ouml;r visas felmeddelandet. Det borde hj&auml;lpa dig att f&ouml;rklara felorsaken. Om du beh&ouml;ver ytterligare hj&auml;lp, v&auml;nligen:',
	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Uppgraderingen slutf&ouml;rdes men p&aring;tr&auml;ffade n&aring;gra problem. L&auml;s beskrivningen h&auml;r ovanf&ouml;r f&ouml;r detaljer om problemen. Om du beh&ouml;ver ytterligare hj&auml;lp, v&auml;nligen:',
	'CoreUpdater_UpgradeComplete' => 'Uppgraderingen slutf&ouml;rd!',
	'CoreUpdater_WarningMessages' => 'Varningsmeddelanden:',
	'CoreUpdater_ErrorDuringPluginsUpdates' => 'Fel under till&auml;ggsupdatering:',
	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'F&ouml;ljande till&auml;gg har avaktiverats automatiskt: %s',
	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik uppdaterades utan problem!',
	'CoreUpdater_ContinueToPiwik' => 'Forts&auml;tt till Piwik',
	'CoreUpdater_UpdateAutomatically' => 'Uppdatera automatiskt',
	'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Det finns en ny version av Piwik tillg&auml;nglig f&ouml;r uppdatering',
	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Du kan automatiskt uppdatera till till version %s eller ladda hem paketet och installera det manuellt',
	'CoreUpdater_DownloadX' => 'Ladda hem %s',
	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik "One Click Update" har avbrutits. Om du inte kan &aring;tg&auml;rda felet &auml;r det rekommenderat att du uppgraderar Piwik manuellt. %s Kolla in %sUppgraderingsdokumentationen%s f&ouml;r att komma ig&aring;ng!',
	'CoreUpdate_DownloadingUpdateFromX' => "Laddar ner uppdatering fr&aring;n %s",
	'CoreUpdate_UnpackingTheUpdate' => "Packar upp uppdateringen",
	'CoreUpdater_VerifyingUnpackedFiles' => 'Verifierar dom uppackade filerna',
	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Skapar en s&auml;kerhetskopia av konfigurationsfilen i %s',
	'CoreUpdater_InstallingTheLatestVersion' => 'Installerar den senaste versionen',
	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik har uppdaterats!',
	'Actions_Actions' => 'H&auml;ndelser',
	'Actions_SubmenuPages' => 'Sidor',
	'Actions_SubmenuOutlinks' => 'Utg&aring;ngssidor',
	'Actions_SubmenuDownloads' => 'Nedladdningar',
	'Actions_ColumnClicks' => 'Klick',
	'Actions_ColumnUniqueClicks' => 'Unika klick',
	'Actions_ColumnDownloads' => 'Nedladdningar',
	'Actions_ColumnUniqueDownloads' => 'Unika nedladdningar',
	'Actions_ColumnPageName' => 'Sidnamn',
	'Actions_ColumnClickedURL' => 'Klickad URL',
	'Actions_ColumnDownloadURL' => 'Nedladdad URL',
	'Dashboard_Dashboard' => 'Kontrollpanel',
	'Dashboard_AddWidget' => 'L&auml;gg till en widget...',
	'Dashboard_DeleteWidgetConfirm' => 'Vill du verkligen ta bort den h&auml;r widgeten fr&aring;n kontrollpanelen?',
	'Dashboard_SelectWidget' => 'V&auml;lj widget att l&auml;gga till i kontrollpanelen',
	'Dashboard_AddPreviewedWidget_js' => 'L&auml;gg till f&ouml;rhandsgranskad widget i kontrollpanelen',
	'Dashboard_WidgetPreview_js' => 'F&ouml;rhandsgranska widget',
	'Dashboard_Close_js' => 'St&auml;ng',
	'Dashboard_TitleWidgetInDashboard_js' => 'Widgeten finns redan i kontrollpanelen',
	'Dashboard_TitleClickToAdd_js' => 'Klicka f&ouml;r att l&auml;gga till kontrollpanelen',
	'Dashboard_LoadingWidget_js' => 'Laddar widget, v&auml;nligen v&auml;nta...',
	'Dashboard_WidgetNotFound_js' => 'Widgeten hittades inte',
	'Referers_Referers' => 'Trafikk&auml;llor',
	'Referers_SearchEngines' => 'S&ouml;kmotorer',
	'Referers_Keywords' => 'S&ouml;kord',
	'Referers_DirectEntry' => 'Direkt trafik',
	'Referers_Websites' => 'Webbplatser',
	'Referers_Campaigns' => 'Kampanjer',
	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (fr&aring;n %2s)',
	'Referers_Evolution' => 'Utveckling under perioden',
	'Referers_Type' => 'Typ av k&auml;lla',
	'Referers_ColumnRefererType' => 'Typ av k&auml;lla',
	'Referers_ColumnSearchEngine' => 'S&ouml;kmotor',
	'Referers_ColumnWebsite' => 'Webbplats',
	'Referers_ColumnWebsitePage' => 'Webbsida',
	'Referers_ColumnKeyword' => 'S&ouml;kord',
	'Referers_ColumnCampaign' => 'Kampanj',
	'Referers_DetailsByRefererType' => 'Detaljer efter h&auml;nvisningstyp',
	'Referers_TypeDirectEntries' => '%s direkta bes&ouml;k',
	'Referers_TypeSearchEngines' => '%s fr&aring;n s&ouml;kmotorer',
	'Referers_TypeWebsites' => '%s fr&aring;n webbplatser',
	'Referers_TypeCampaigns' => '%s fr&aring;n kampanjer',
	'Referers_Distinct' => 'Distinkta h&auml;nvisningar efter h&auml;nvisningstyp',
	'Referers_DistinctSearchEngines' => 'distinkta s&ouml;kmotorer',
	'Referers_DistinctKeywords' => 'distinkta s&ouml;kord',
	'Referers_DistinctCampaigns' => 'distinkta kampanjer',
	'Referers_DistinctWebsites' => 'distinct webplatser',
	'Referers_UsingNDistinctUrls' => ' (anv&auml;nder %2s distinkta urler)',
	'Referers_SubmenuEvolution' => 'Utveckling',
	'Referers_SubmenuSearchEngines' => 'S&ouml;kmotorer och s&ouml;kord',
	'Referers_SubmenuWebsites' => 'Webbplatser',
	'Referers_SubmenuCampaigns' => 'Kampanjer',
	'Referers_WidgetKeywords' => 'Popul&auml;ra s&ouml;kord',
	'Referers_WidgetCampaigns' => 'Lista &ouml;ver kampanjer',
	'Referers_WidgetExternalWebsites' => 'Lista &ouml;ver externa webbplatser',
	'Referers_WidgetSearchEngines' => 'B&auml;sta s&ouml;kmotorerna',
	'Referers_WidgetOverview' => '&ouml;versikt',
	'UserSettings_VisitorSettings' => 'Bes&ouml;kares inst&auml;llningar',
	'UserSettings_BrowserFamilies' => 'Webbl&auml;sarfamiljer',
	'UserSettings_Browsers' => 'Webbl&auml;sare',
	'UserSettings_Plugins' => 'Till&auml;gg',
	'UserSettings_Configurations' => 'Konfigurationer',
	'UserSettings_OperatingSystems' => 'Operativsystem',
	'UserSettings_Resolutions' => 'Sk&auml;rmuppl&ouml;sning',
	'UserSettings_WideScreen' => 'Wide Screen',
	'UserSettings_ColumnBrowserFamily' => 'Webbl&auml;sarfamilj',
	'UserSettings_ColumnBrowser' => 'Webbl&auml;sare',
	'UserSettings_ColumnPlugin' => 'Till&auml;gg',
	'UserSettings_ColumnConfiguration' => 'Konfiguration',
	'UserSettings_ColumnOperatingSystem' => 'Operativsystem',
	'UserSettings_ColumnResolution' => 'Sk&auml;rmuppl&ouml;sning',
	'UserSettings_ColumnTypeOfScreen' => 'Typ av sk&auml;rm',
	'UserSettings_WidgetResolutions' => 'Sk&auml;rmuppl&ouml;sning',
	'UserSettings_WidgetBrowsers' => 'Webbl&auml;sare',
	'UserSettings_WidgetPlugins' => 'Lista med till&auml;gg',
	'UserSettings_WidgetWidescreen' => 'Normal / Widescreen',
	'UserSettings_WidgetBrowserFamilies' => 'Webbl&auml;sare efter familj',
	'UserSettings_WidgetOperatingSystems' => 'Operativsystem',
	'UserSettings_WidgetGlobalVisitors' => 'Konfigurationer',
	'UserSettings_SubmenuSettings' => 'Inst&auml;llningar',
	'UserCountry_Country' => 'Land',
	'UserCountry_Continent' => 'Kontinent',
	'UserCountry_DistinctCountries' => '%s kontinenter',
	'UserCountry_SubmenuLocations' => 'Platser',
	'UserCountry_WidgetContinents' => 'Bes&ouml;karkontinenter',
	'UserCountry_WidgetCountries' => 'Bes&ouml;karl&auml;nder',
	'UserCountry_country_ac' => 'Ascension',
	'UserCountry_country_ad' => 'Andorra',
	'UserCountry_country_ae' => 'F&ouml;renade arabemiraten',
	'UserCountry_country_af' => 'Afghanistan',
	'UserCountry_country_ag' => 'Antigua och Barbuda',
	'UserCountry_country_ai' => 'Anguilla',
	'UserCountry_country_al' => 'Albanien',
	'UserCountry_country_am' => 'Armenien',
	'UserCountry_country_an' => 'Nederl&auml;ndska Antillerna',
	'UserCountry_country_ao' => 'Angola',
	'UserCountry_country_aq' => 'Antarktis',
	'UserCountry_country_ar' => 'Argentina',
	'UserCountry_country_as' => 'Amerikanska Samoa',
	'UserCountry_country_at' => '&Ouml;sterrike',
	'UserCountry_country_au' => 'Australien',
	'UserCountry_country_aw' => 'Aruba',
	'UserCountry_country_ax' => '&Aring;land',
	'UserCountry_country_az' => 'Azerbajdzjan',
	'UserCountry_country_ba' => 'Bosnien och Hercegovina',
	'UserCountry_country_bb' => 'Barbados',
	'UserCountry_country_bd' => 'Bangladesh',
	'UserCountry_country_be' => 'Belgien',
	'UserCountry_country_bf' => 'Burkina Faso',
	'UserCountry_country_bg' => 'Bulgarien',
	'UserCountry_country_bh' => 'Bahrain',
	'UserCountry_country_bi' => 'Burundi',
	'UserCountry_country_bj' => 'Benin',
	'UserCountry_country_bl' => 'St Barthélemy',
	'UserCountry_country_bm' => 'Bermuda',
	'UserCountry_country_bn' => 'Brunei',
	'UserCountry_country_bo' => 'Bolivia',
	'UserCountry_country_br' => 'Brasilien',
	'UserCountry_country_bs' => 'Bahamas',
	'UserCountry_country_bt' => 'Bhutan',
	'UserCountry_country_bu' => 'Burma',
	'UserCountry_country_bv' => 'Bouvet&ouml;n',
	'UserCountry_country_bw' => 'Botswana',
	'UserCountry_country_by' => 'Vitryssland',
	'UserCountry_country_bz' => 'Belize',
	'UserCountry_country_ca' => 'Kanada',
	'UserCountry_country_cc' => 'Kokos&ouml;arna',
	'UserCountry_country_cd' => 'Kongo-Kinshasa',
	'UserCountry_country_cf' => 'Centralafrikanska republiken',
	'UserCountry_country_cg' => 'Republiken Kongo',
	'UserCountry_country_ch' => 'Schweiz',
	'UserCountry_country_ci' => 'Elfenbenskusten',
	'UserCountry_country_ck' => 'Cook&ouml;arna',
	'UserCountry_country_cl' => 'Chile',
	'UserCountry_country_cm' => 'Kamerun',
	'UserCountry_country_cn' => 'Kina',
	'UserCountry_country_co' => 'Colombia',
	'UserCountry_country_cp' => 'Clipperton',
	'UserCountry_country_cr' => 'Costa Rica',
	'UserCountry_country_cs' => 'Serbien och Montenegro',
	'UserCountry_country_cu' => 'Kuba',
	'UserCountry_country_cv' => 'Kap Verde',
	'UserCountry_country_cx' => 'Jul&ouml;n',
	'UserCountry_country_cy' => 'Cypern',
	'UserCountry_country_cz' => 'Tjeckien',
	'UserCountry_country_de' => 'Tyskland',
	'UserCountry_country_dg' => 'Diego Garcia',
	'UserCountry_country_dj' => 'Djibouti',
	'UserCountry_country_dk' => 'Danmark',
	'UserCountry_country_dm' => 'Dominica',
	'UserCountry_country_do' => 'Dominikanska republiken',
	'UserCountry_country_dz' => 'Algeriet',
	'UserCountry_country_ea' => 'Ceuta och Melilla',
	'UserCountry_country_ec' => 'Ecuador',
	'UserCountry_country_ee' => 'Estland',
	'UserCountry_country_eg' => 'Egypten',
	'UserCountry_country_eh' => 'V&auml;stsahara',
	'UserCountry_country_er' => 'Eritrea',
	'UserCountry_country_es' => 'Spanien',
	'UserCountry_country_et' => 'Etiopien',
	'UserCountry_country_eu' => 'Europeiska Unionen',
	'UserCountry_country_fi' => 'Finland',
	'UserCountry_country_fj' => 'Fiji',
	'UserCountry_country_fk' => 'Falklands&ouml;arna',
	'UserCountry_country_fm' => 'Mikronesiens federerade stater',
	'UserCountry_country_fo' => 'F&auml;r&ouml;arna',
	'UserCountry_country_fr' => 'Frankrike',
	'UserCountry_country_fx' => 'Frankrike, Metropolitan',
	'UserCountry_country_ga' => 'Gabon',
	'UserCountry_country_gb' => 'Storbrittanien',
	'UserCountry_country_gd' => 'Grenada',
	'UserCountry_country_ge' => 'Georgien',
	'UserCountry_country_gf' => 'Franska Guyana',
	'UserCountry_country_gg' => 'Guernsey',
	'UserCountry_country_gh' => 'Ghana',
	'UserCountry_country_gi' => 'Gibraltar',
	'UserCountry_country_gl' => 'Gr&ouml;nland',
	'UserCountry_country_gm' => 'Gambia',
	'UserCountry_country_gn' => 'Guinea',
	'UserCountry_country_gp' => 'Guadeloupe',
	'UserCountry_country_gq' => 'Ekvatorialguinea',
	'UserCountry_country_gr' => 'Grekland',
	'UserCountry_country_gs' => 'Sydgeorgien',
	'UserCountry_country_gt' => 'Guatemala',
	'UserCountry_country_gu' => 'Guam',
	'UserCountry_country_gw' => 'Guinea-Bissau',
	'UserCountry_country_gy' => 'Guyana',
	'UserCountry_country_hk' => 'Hong Kong',
	'UserCountry_country_hm' => 'Heard- och McDonalds&ouml;arna',
	'UserCountry_country_hn' => 'Honduras',
	'UserCountry_country_hr' => 'Kroatien',
	'UserCountry_country_ht' => 'Haiti',
	'UserCountry_country_hu' => 'Ungern',
	'UserCountry_country_ic' => 'Kanarie&ouml;arna',
	'UserCountry_country_id' => 'Indonesien',
	'UserCountry_country_ie' => 'Irland',
	'UserCountry_country_il' => 'Israel',
	'UserCountry_country_im' => 'Isle of Man',
	'UserCountry_country_in' => 'Indien',
	'UserCountry_country_io' => 'Brittiska territoriet i Indiska oceanen',
	'UserCountry_country_iq' => 'Irak',
	'UserCountry_country_ir' => 'Iran',
	'UserCountry_country_is' => 'Island',
	'UserCountry_country_it' => 'Italien',
	'UserCountry_country_je' => 'Jersey',
	'UserCountry_country_jm' => 'Jamaica',
	'UserCountry_country_jo' => 'Jordanien',
	'UserCountry_country_jp' => 'Japan',
	'UserCountry_country_ke' => 'Kenya',
	'UserCountry_country_kg' => 'Kirgizistan',
	'UserCountry_country_kh' => 'Kambodja',
	'UserCountry_country_ki' => 'Kiribati',
	'UserCountry_country_km' => 'Komorerna',
	'UserCountry_country_kn' => 'Saint Christopher och Nevis',
	'UserCountry_country_kp' => 'Nordkorea',
	'UserCountry_country_kr' => 'Sydkorea',
	'UserCountry_country_kw' => 'Kuwait',
	'UserCountry_country_ky' => 'Cayman&ouml;arna',
	'UserCountry_country_kz' => 'Kazakstan',
	'UserCountry_country_la' => 'Laos',
	'UserCountry_country_lb' => 'Libanon',
	'UserCountry_country_lc' => 'Saint Lucia',
	'UserCountry_country_li' => 'Liechtenstein',
	'UserCountry_country_lk' => 'Sri Lanka',
	'UserCountry_country_lr' => 'Liberia',
	'UserCountry_country_ls' => 'Lesotho',
	'UserCountry_country_lt' => 'Litauen',
	'UserCountry_country_lu' => 'Luxemburg',
	'UserCountry_country_lv' => 'Lettland',
	'UserCountry_country_ly' => 'Libyen',
	'UserCountry_country_ma' => 'Marocko',
	'UserCountry_country_mc' => 'Monaco',
	'UserCountry_country_md' => 'Moldavien',
	'UserCountry_country_me' => 'Montenegro',
	'UserCountry_country_mf' => 'Saint Martin',
	'UserCountry_country_mg' => 'Madagaskar',
	'UserCountry_country_mh' => 'Marshall&ouml;arna',
	'UserCountry_country_mk' => 'Makedonien',
	'UserCountry_country_ml' => 'Mali',
	'UserCountry_country_mm' => 'Myanmar',
	'UserCountry_country_mn' => 'Mongoliet',
	'UserCountry_country_mo' => 'Macao',
	'UserCountry_country_mp' => 'Nordmarianerna',
	'UserCountry_country_mq' => 'Martinique',
	'UserCountry_country_mr' => 'Mauretanien',
	'UserCountry_country_ms' => 'Montserrat',
	'UserCountry_country_mt' => 'Malta',
	'UserCountry_country_mu' => 'Mauritius',
	'UserCountry_country_mv' => 'Maldiverna',
	'UserCountry_country_mw' => 'Malawi',
	'UserCountry_country_mx' => 'Mexiko',
	'UserCountry_country_my' => 'Malaysia',
	'UserCountry_country_mz' => 'Moçambique',
	'UserCountry_country_na' => 'Namibia',
	'UserCountry_country_nc' => 'Nya Kaledonien',
	'UserCountry_country_ne' => 'Niger',
	'UserCountry_country_nf' => 'Norfolk&ouml;n',
	'UserCountry_country_ng' => 'Nigeria',
	'UserCountry_country_ni' => 'Nicaragua',
	'UserCountry_country_nl' => 'Nederl&auml;nderna',
	'UserCountry_country_no' => 'Norge',
	'UserCountry_country_np' => 'Nepal',
	'UserCountry_country_nr' => 'Nauru',
	'UserCountry_country_nt' => 'Neutral Zone',
	'UserCountry_country_nu' => 'Niue',
	'UserCountry_country_nz' => 'Nya Zeeland',
	'UserCountry_country_om' => 'Oman',
	'UserCountry_country_pa' => 'Panama',
	'UserCountry_country_pe' => 'Peru',
	'UserCountry_country_pf' => 'Franska Polynesien',
	'UserCountry_country_pg' => 'Papua Nya Guinea',
	'UserCountry_country_ph' => 'Filippinerna',
	'UserCountry_country_pk' => 'Pakistan',
	'UserCountry_country_pl' => 'Polen',
	'UserCountry_country_pm' => 'Saint-Pierre och Miquelon',
	'UserCountry_country_pn' => 'Pitcairn&ouml;arna',
	'UserCountry_country_pr' => 'Puerto Rico',
	'UserCountry_country_ps' => 'Palestina',
	'UserCountry_country_pt' => 'Portugal',
	'UserCountry_country_pw' => 'Palau',
	'UserCountry_country_py' => 'Paraguay',
	'UserCountry_country_qa' => 'Qatar',
	'UserCountry_country_re' => 'Réunion',
	'UserCountry_country_ro' => 'Rum&auml;nien',
	'UserCountry_country_ru' => 'Ryssland',
	'UserCountry_country_rs' => 'Serbien',
	'UserCountry_country_rw' => 'Rwanda',
	'UserCountry_country_sa' => 'Saudiarabien',
	'UserCountry_country_sb' => 'Salomon&ouml;arna',
	'UserCountry_country_sc' => 'Seychellerna',
	'UserCountry_country_sd' => 'Sudan',
	'UserCountry_country_se' => 'Sverige',
	'UserCountry_country_sf' => 'Finland',
	'UserCountry_country_sg' => 'Singapore',
	'UserCountry_country_sh' => 'Sankt Helena',
	'UserCountry_country_si' => 'Slovenien',
	'UserCountry_country_sj' => 'Svalbard',
	'UserCountry_country_sk' => 'Slovakien',
	'UserCountry_country_sl' => 'Sierra Leone',
	'UserCountry_country_sm' => 'San Marino',
	'UserCountry_country_sn' => 'Senegal',
	'UserCountry_country_so' => 'Somalia',
	'UserCountry_country_sr' => 'Surinam',
	'UserCountry_country_st' => 'São Tomé och Príncipe',
	'UserCountry_country_su' => 'Sovjetunionen',
	'UserCountry_country_sv' => 'El Salvador',
	'UserCountry_country_sy' => 'Syrien',
	'UserCountry_country_sz' => 'Swaziland',
	'UserCountry_country_ta' => 'Tristan da Cunha',
	'UserCountry_country_tc' => 'Turks- och Caicos&ouml;arna',
	'UserCountry_country_td' => 'Tchad',
	'UserCountry_country_tf' => 'Franska sydterritorierna',
	'UserCountry_country_tg' => 'Togo',
	'UserCountry_country_th' => 'Thailand',
	'UserCountry_country_tj' => 'Tadzjikistan',
	'UserCountry_country_tk' => 'Tokelau&ouml;arna',
	'UserCountry_country_tl' => '&Ouml;sttimor',
	'UserCountry_country_tm' => 'Turkmenistan',
	'UserCountry_country_tn' => 'Tunisien',
	'UserCountry_country_to' => 'Tonga',
	'UserCountry_country_tp' => '&ouml;sttimor',
	'UserCountry_country_tr' => 'Turkiet',
	'UserCountry_country_tt' => 'Trinidad och Tobago',
	'UserCountry_country_tv' => 'Tuvalu',
	'UserCountry_country_tw' => 'Taiwan',
	'UserCountry_country_tz' => 'Tanzania',
	'UserCountry_country_ua' => 'Ukraina',
	'UserCountry_country_ug' => 'Uganda',
	'UserCountry_country_uk' => 'Storbritannien',
	'UserCountry_country_um' => 'F&ouml;renta staternas avl&auml;gset bel&auml;gna &ouml;ar',
	'UserCountry_country_us' => 'USA',
	'UserCountry_country_uy' => 'Uruguay',
	'UserCountry_country_uz' => 'Uzbekistan',
	'UserCountry_country_va' => 'Vatikanstaten',
	'UserCountry_country_vc' => 'Saint Vincent och Grenadinerna',
	'UserCountry_country_ve' => 'Venezuela',
	'UserCountry_country_vg' => 'Brittiska Jungfru&ouml;arna',
	'UserCountry_country_vi' => 'Amerikanska Jungfru&ouml;arna',
	'UserCountry_country_vn' => 'Vietnam',
	'UserCountry_country_vu' => 'Vanuatu',
	'UserCountry_country_wf' => 'Wallis- och Futuna&ouml;arna',
	'UserCountry_country_ws' => 'Samoa',
	'UserCountry_country_ye' => 'Jemen',
	'UserCountry_country_yt' => 'Mayotte',
	'UserCountry_country_yu' => 'Jugoslavien',
	'UserCountry_country_za' => 'Sydafrika',
	'UserCountry_country_zm' => 'Zambia',
	'UserCountry_country_zr' => 'Zaire',
	'UserCountry_country_zw' => 'Zimbabwe',
	'UserCountry_continent_eur' => 'Europa',
	'UserCountry_continent_afr' => 'Afrika',
	'UserCountry_continent_asi' => 'Asien',
	'UserCountry_continent_ams' => 'Syd- och Centralamerika',
	'UserCountry_continent_amn' => 'Nordamerika',
	'UserCountry_continent_oce' => 'Oceanien',
	'VisitsSummary_NbVisits' => '%s bes&ouml;k',
	'VisitsSummary_NbUniqueVisitors' => '%s unika bes&ouml;kare',
	'VisitsSummary_NbActions' => '%s h&auml;ndelser (sidvisningar)',
	'VisitsSummary_TotalTime' => '%s har spenderats av bes&ouml;karna',
	'VisitsSummary_MaxNbActions' => '%s h&auml;ndelser som mest i ett bes&ouml;k',
	'VisitsSummary_NbVisitsBounced' => '%s bes&ouml;kare har studsat (l&auml;mnat sidan efter en sidvisning)',
	'VisitsSummary_EvolutionOverLastPeriods' => 'Utveckling dom senaste %s',
	'VisitsSummary_Report' => 'Rapport',
	'VisitsSummary_GenerateTime' => 'Sidan genererades p&aring; %s sekunder',
	'VisitsSummary_GenerateQueries' => '%s fr&aring;gor skickade',
	'VisitsSummary_WidgetLastVisits' => 'Senaste bes&ouml;ken',
	'VisitsSummary_WidgetVisits' => 'Bes&ouml;ks&ouml;versikt',
	'VisitsSummary_WidgetLastVisitors' => 'Senaste unika bes&ouml;ken',
	'VisitsSummary_WidgetOverviewGraph' => '&ouml;versikt med diagram',
	'VisitsSummary_SubmenuOverview' => '&ouml;versikt',
	'VisitFrequency_Evolution' => 'Utveckling &ouml;ver perioden',
	'VisitFrequency_ColumnReturningVisits' => '&Aring;terv&auml;ndande bes&ouml;k',
	'VisitFrequency_ColumnActionsByReturningVisits' => 'H&auml;ndelser av &aring;terv&auml;ndande bes&ouml;k',
	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Maximalt antal h&auml;ndelser av ett &aring;terv&auml;ndande bes&ouml;k',
	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Total tid spenderad i &aring;terv&auml;ndande bes&ouml;k (i sekunder)',
	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Avvisningsfrekvensen f&ouml;r &aring;terkommande bes&ouml;k',
	'VisitFrequency_ReturnVisits' => '%s &aring;terkommande bes&ouml;k',
	'VisitFrequency_ReturnActions' => '%s h&auml;ndelser av dom &aring;terkommande bes&ouml;ken',
	'VisitFrequency_ReturnMaxActions' => '%s h&auml;ndelser som mest i ett &aring;terkommande bes&ouml;k',
	'VisitFrequency_ReturnTotalTime' => '%s har spenderats av dom &aring;terkommande bes&ouml;ken',
	'VisitFrequency_ReturnBounceRate' => '%s g&aring;nger som en &aring;terkommande bes&ouml;kare har studsat (l&auml;mnat sidan efter en sidvisning)',
	'VisitFrequency_WidgetOverview' => 'Frekvens&ouml;versikt',
	'VisitFrequency_WidgetGraphReturning' => 'Diagram f&ouml;r &aring;terkommande bes&ouml;k',
	'VisitFrequency_SubmenuFrequency' => 'Frekvens',
	'VisitTime_LocalTime' => 'Bes&ouml;k efter lokal tid',
	'VisitTime_ServerTime' => 'Bes&ouml;k efter servertid',
	'VisitTime_ColumnServerTime' => 'Servertid',
	'VisitTime_ColumnLocalTime' => 'Lokal tid',
	'VisitTime_WidgetLocalTime' => 'Bes&ouml;k efter lokal tid',
	'VisitTime_WidgetServerTime' => 'Bes&ouml;k efter servertid',
	'VisitTime_SubmenuTimes' => 'Tider',
	'VisitTime_NHour' => '%sh',
	'VisitorInterest_VisitsPerDuration' => 'Tid per bes&ouml;k',
	'VisitorInterest_VisitsPerNbOfPages' => 'Sidvisningar per bes&ouml;k',
	'VisitorInterest_ColumnVisitDuration' => 'Bes&ouml;ksl&auml;ngd',
	'VisitorInterest_ColumnPagesPerVisit' => 'Sidvisningar per bes&ouml;k',
	'VisitorInterest_WidgetLengths' => 'Bes&ouml;ksl&auml;ngd',
	'VisitorInterest_WidgetPages' => 'Sidvisningar per bes&ouml;k',
	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frekvens och lojalitet',
	'VisitorInterest_PlusXMin' => '%s min',
	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
	'VisitorInterest_OnePage' => '1 sida',
	'VisitorInterest_NPages' => '%s sidor',
	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
	'Login_LoginPasswordNotCorrect' => 'Anv&auml;ndarnamn och l&ouml;senord &auml;r felaktigt',
	'Login_Login' => 'Anv&auml;ndarnamn',
	'Login_Password' => 'L&ouml;senord',
	'Login_LoginOrEmail' => 'Anv&auml;ndarnamn eller e-post',
	'Login_LogIn' => 'Logga in',
	'Login_Logout' => 'Logga ut',
	'Login_LostYourPassword' => 'F&ouml;rlorat ditt l&ouml;senord?',
	'Login_RemindPassword' => 'P&aring;minn l&ouml;senord',
	'Login_PasswordReminder' => 'V&auml;nligen fyll i ditt anv&auml;ndarnamn eller din e-postadress. Du kommer att f&aring; ett nytt l&ouml;senord skickat via e-post.',
	'Login_InvalidUsernameEmail' => 'Felaktigt anv&auml;ndarnamn och/eller e-postadress',
	'Login_MailTopicPasswordRecovery' => '&Aring;terst&auml;ll l&ouml;senord',
	'Login_MailPasswordRecoveryBody' => 'Hej %1s, \n\n Ditt nya l&ouml;senord &auml;r: %2s \n\n Nu kan du logga in p&aring;: %3s',
	'Login_PasswordSent' => 'L&ouml;senordet har skickats. Kontrollera din e-post.',
	'Login_ContactAdmin' => 'M&ouml;jlig orsak: din v&auml;rd kan ha avaktiverat mail() funktionen. <br />Var v&auml;nlig kontakta din Piwik-administrat&ouml;r',
	'UsersManager_UsersManagement' => 'Anv&auml;ndarhantering',
	'UsersManager_UsersManagementMainDescription' => 'Skapa nya eller redigera befintliga anv&auml;ndare. D&auml;refter kan du st&auml;lla in deras r&auml;ttigheter h&auml;r ovanf&ouml;r.',
	'UsersManager_ManageAccess' => 'Hantera r&auml;ttigheter',
	'UsersManager_MainDescription' => 'Best&auml;m vilka anv&auml;ndare som ska ha tillg&aring;ng till analyserna p&aring; din webbplats. Du kan ocks&aring; st&auml;lla in r&auml;ttigheterna f&ouml;r alla webbplatser p&aring; en g&aring;ng.',
	'UsersManager_Sites' => 'Webbplatser',
	'UsersManager_AllWebsites' => 'Alla webbplatser',
	'UsersManager_ApplyToAllWebsites' => 'Verkst&auml;ll p&aring; alla webbplatser',
	'UsersManager_User' => 'Anv&auml;ndare',
	'UsersManager_PrivNone' => 'Ingen beh&ouml;righet',
	'UsersManager_PrivView' => 'Visa',
	'UsersManager_PrivAdmin' => 'Admin',
	'UsersManager_ChangeAllConfirm' => '&Auml;r du s&auml;ker p&aring; att du vill &auml;ndra r&auml;ttigheterna f&ouml;r \'%s\' p&aring; alla webbplatser?',
	'UsersManager_Login' => 'Anv&auml;ndarnamn',
	'UsersManager_Password' => 'L&ouml;senord',
	'UsersManager_Email' => 'E-post',
	'UsersManager_Alias' => 'Alias',
	'UsersManager_Token' => 'token_auth',
	'UsersManager_Edit' => '&Auml;ndra',
	'UsersManager_AddUser' => 'L&auml;gg till en ny anv&auml;ndare',
	'UsersManager_MenuUsers' => 'Anv&auml;ndare',
	'UsersManager_DeleteConfirm_js' => '&Auml;r du s&auml;ker p&aring; att du vill radera \'%s\'?',
	'UsersManager_ExceptionLoginExists' => 'Anv&auml;ndarnamnet \'%s\' finns redan.',
	'UsersManager_ExceptionEmailExists' => 'En anv&auml;ndare med e-postadressen \'%s\' finns redan.',
	'UsersManager_ExceptionInvalidLoginFormat' => 'Anv&auml;ndarnamnet f&aring;r endast best&aring; av bokst&auml;ver, siffror eller tecknen \'_\' eller \'-\' eller \'.\'',
	'UsersManager_ExceptionInvalidPassword' => 'L&ouml;senordet m&aring;ste ha en l&auml;ngd mellan 6 och 26 tecken.',
	'UsersManager_ExceptionInvalidEmail' => 'E-postadressen har inget giltigt format.',
	'UsersManager_ExceptionDeleteDoesNotExist' => 'Anv&auml;ndaren \'%s\' finns inte och kan d&auml;rf&ouml;r inte raderas.',
	'UsersManager_ExceptionAdminAnonymous' => 'Du kan inte ge anv&auml;ndaren \'anonymous\' administrat&ouml;rsr&auml;ttigheter.',
	'UsersManager_ExceptionEditAnonymous' => 'Den anonyma anv&auml;ndare kan inte redigeras eller tas bort. Den anv&auml;nds av Piwik f&ouml;r att definiera en anv&auml;ndare som inte har loggat in &auml;nnu. Till exempel kan du g&ouml;ra din statistik tillg&auml;nglig f&ouml;r allm&auml;nheten genom att ge \'anonymous\' r&auml;ttigheten \'visa\'.',
	'UsersManager_ExceptionSuperUser' => 'Den beg&auml;rda anv&aulm;ndaren &aulm;r huvudanv&auml;ndaren och kan inte f&ouml;rfr&aring;gas, &aulm;ndras eller tas bort via APIn. Du kan &aulm;ndra huvudanv&aulm;ndarens detaljer i konfigurationsfilen f&ouml;r Piwik.',
	'UsersManager_ExceptionUserDoesNotExist' => 'Anv&auml;ndaren \'%s\' finns inte.',
	'UsersManager_ExceptionAccessValues' => 'Parametern m&aring;ste ha en av f&ouml;ljande v&auml;rden: [ %s ]',
	'SitesManager_Sites' => 'Webbplatser',
	'SitesManager_WebsitesManagement' => 'Webbplatser',
	'SitesManager_MainDescription' => 'Dina analyser beh&ouml;ver webbplatser! L&auml;gg till, uppdatera, radera webbplatser och visa Javascript-kod att l&auml;gga till p&aring; dina sidor.',
	'SitesManager_JsTrackingTag' => 'Javascript-sp&aring;rningskod',
	'SitesManager_JsTrackingTagHelp' => 'H&auml;r &auml;r sp&aring;rningskod som ska l&auml;ggas in p&aring; alla dina sidor',
	'SitesManager_ShowTrackingTag' => 'Visa sp&aring;rningskod',
	'SitesManager_NoWebsites' => 'Do har inga webbplatser att administrera',
	'SitesManager_AddSite' => 'L&auml;gg till webbplats',
	'SitesManager_Id' => 'Id',
	'SitesManager_Name' => 'Namn',
	'SitesManager_Urls' => 'URLer',
	'SitesManager_MenuSites' => 'Webbplatser',
	'SitesManager_DeleteConfirm_js' => '&Auml;r du s&auml;ker p&aring; att du vill radera webbplatsen %s?',
	'SitesManager_ExceptionDeleteSite' => 'Det g&aring;r inte att radera den h&auml;r webbplatsen eftersom det &auml;r den enda registrerade. L&auml;gg till en ny webbplats f&ouml;rst, radera d&auml;refter den h&auml;r.',
	'SitesManager_ExceptionNoUrl' => 'Du m&aring;ste ange minst en URL f&ouml;r webbplatsen',
	'SitesManager_ExceptionEmptyName' => 'Webbplatsen m&aring;ste ha ett namn',
	'SitesManager_ExceptionInvalidUrl' => '\'%s\' &auml;r inte en giltig URL.',
	'Installation_Installation' => 'Installation',
	'Installation_InstallationStatus' => 'Installationsstatus',
	'Installation_PercentDone' => '%s %% Klart',
	'Installation_NoConfigFound' => 'Du f&ouml;rs&ouml;ker visa en Piwiksida utan att n&aring;gon konfigurationsfil hittades.<br /><b>&nbsp;&nbsp;&raquo; Du kan <a href=\'index.php\'>installera Piwik nu</a></b><br /><small>Om du har installerat Piwik f&ouml;rut och har analyser lagrade i databasen, oroa dig inte, du kan &aring;teranv&auml;nda samma analyser och beh&aring;lla befintlig data!</small>',
	'Installation_MysqlSetup' => 'Mysql databasinst&auml;llning',
	'Installation_MysqlErrorConnect' => 'Fel vid anslutning till MySQL databasen',
	'Installation_JsTag' => 'Javascript kod',
	'Installation_JsTagHelp' => '<p>F&ouml;r att r&auml;kna alla bes&ouml;k m&aring;ste du l&auml;gga till Javascript-koden p&aring; alla dina sidor.</p><p>Dina sidor beh&ouml;ver inte vara gjorda med PHP, Piwik fungerar p&aring; alla typer av sidor (oavsett om det &auml;r HTML, ASP, Perl eller n&aring;got annat spr&aring;k).</p><p>H&auml;r &auml;r koden du m&aring;ste l&auml;gga till: (kopiera och klistra in p&aring; alla dina sidor)</p>',
	'Installation_Congratulations' => 'Grattis',
	'Installation_CongratulationsHelp' => '<p>Grattis! Din installation av Piwik &auml;r klar.</p><p>Kontrollera att din javascript-kod finns p&aring; alla dina sidor, inv&auml;nta sedan p&aring; dina f&ouml;rsta bes&ouml;kare!',
	'Installation_ContinueToPiwik' => 'Forts&auml;tt till Piwik',
	'Installation_SetupWebsite' => 'L&auml;gg till en webbplats',
	'Installation_SetupWebsiteError' => 'Ett fel p&aring;tr&auml;ffades n&auml;r webbplatsen skulle l&auml;ggas till',
	'Installation_GeneralSetup' => 'Allm&auml;nna inst&auml;llningar',
	'Installation_GeneralSetupSuccess' => 'Allm&auml;nna inst&auml;llningar slutf&ouml;rdes utan problbem',
	'Installation_SuperUserLogin' => 'login f&ouml; superanv&auml;ndare',
	'Installation_Password' => 'l&ouml;senord',
	'Installation_PasswordRepeat' => 'l&ouml;senord (repetera)',
	'Installation_Email' => 'e-post',
	'Installation_SecurityNewsletter' => 'notifiera mig om uppdateringar och s&auml;kerhetsbrister i Piwik via e-post',
	'Installation_CommunityNewsletter' => 'skicka e-post med community-uppdateringar (nya till&auml;gg, funktioner m.m.)',
	'Installation_PasswordDoNotMatch' => 'l&ouml;senorden matchar inte varandra',
	'Installation_SubmitGo' => 'K&ouml;r!',
	'Installation_SystemCheck' => 'Systemkontroll',
	'Installation_SystemCheckPhp' => 'PHP-version',
	'Installation_SystemCheckPdo' => 'Pdo-till&auml;gg',
	'Installation_SystemCheckPdoMysql' => 'Pdo_Mysql-till&auml;gg',
	'Installation_SystemCheckPdoError' => 'Du m&aring;ste aktivera PDO och PDO_MYSQL-till&auml;ggen i din php.ini-fil.',
	'Installation_SystemCheckPdoHelp' => 'P&aring; windows-servrar kan du l&auml;gga till f&ouml;ljande rader i din php.ini %s<br /><br />P&aring; en linux-server kan du kompilera php med f&ouml;ljande val %s L&auml;gg till f&ouml;ljande rader i din php.ini %s<br /><br />Mer informations finns p&aring; <a style="color:red" href="http://php.net/pdo">PHP\'s webbplats</a>.',
	'Installation_SystemCheckWriteDirs' => 'Mappar med skrivbeh&ouml;righet',
	'Installation_SystemCheckWriteDirsHelp' => 'F&ouml;r att fixa det h&auml;r problemet p&aring; ditt Linuxsystem, f&ouml;rs&ouml;k att skriva f&ouml;ljande kommando(n)',
	'Installation_SystemCheckMemoryLimit' => 'Minnesgr&auml;ns',
	'Installation_SystemCheckMemoryLimitHelp' => 'P&aring; sidor med mycket trafik kan arkiveringsprocessen kr&auml;va mer minne &auml;n det som till&aring;ts just nu.<br />Se &ouml;ver direktivet memory_limit i din php.ini om det beh&ouml;vs.',
	'Installation_SystemCheckGD' => 'GD &gt; 2.x (grafik)',
	'Installation_SystemCheckGDHelp' => 'Sparklines (sm&aring; diagram) kommer inte att fungera',
	'Installation_SystemCheckTimeLimit' => 'set_time_limit() till&aring;ts',
	'Installation_SystemCheckTimeLimitHelp' => 'P&aring; sidor med mycket trafik kan arkiveringsprocessen kr&auml;va mer tid &auml;n vad som till&aring;ts just nu.<br />Se &ouml;ver direktivet max_execution_time i din php.ini om det beh&ouml;vs.',
	'Installation_SystemCheckMail' => 'mail() till&aring;ts',
	'Installation_SystemCheckError' => 'Ett fel p&aring;tr&auml;ffades - det m&aring;ste r&auml;ttas till innan du kan forts&auml;tta',
	'Installation_SystemCheckWarning' => 'Piwik kommer fungera men vissa funktioner kan saknas',
	'Installation_Tables' => 'Skapar tabeller',
	'Installation_TablesWithSameNamesFound' => 'N&aring;gra %s tabeller i din databas %s har samma namn som dom tabeller Piwik f&ouml;rs&ouml;ker att skapa',
	'Installation_TablesFound' => 'F&ouml;ljande tabeller hittades i databasen',
	'Installation_TablesWarningHelp' => 'V&auml;lj att antingen &aring;teranv&auml;nda befintliga tabeller i databasen eller v&auml;lj en ren installation f&ouml;r att radera all befintlig data.',
	'Installation_TablesReuse' => '&Aring;teranv&auml;nd befintlig tabeller',
	'Installation_TablesDelete' => 'Radera befintliga tabeller',
	'Installation_TablesDeletedSuccess' => 'Befintliga Piwik-tabeller raderades utan problem',
	'Installation_TablesCreatedSuccess' => 'Tabeller skapades utan problem!',
	'Installation_DatabaseCreatedSuccess' => 'Databasen %s skapades utan problem!',
	'Installation_GoBackAndDefinePrefix' => 'G&aring; tillbaka och v&auml;lj ett prefix f&ouml;r Piwiks tabeller',
	'Installation_ConfirmDeleteExistingTables' => '&Auml;r du s&auml;ker p&aring; att du vill ta bort f&ouml;ljande tabeller: &s fr&aring;n din databas? VARNING: DATA FR&Aring;N DESSA TABELLER KAN INTE &Aring;TERSKAPAS!',
	'Installation_Welcome' => 'V&auml;lkommen!',
	'Installation_WelcomeHelp' => '<p>Piwik &auml;r en open source programvara f&ouml;r webbplatsanalys som g&ouml;r det enkelt att samla in information om dina bes&ouml;kare.</p><p>Den &auml;r processen &auml;r uppdelad i %s enkla steg och kommer ta ca 5 minuter.</p>',
	'Installation_ErrorInvalidState' => 'Fel: det ser ut som att du f&ouml;rs&ouml;kt hoppa &ouml;ver ett steg i installationsprocessen, eller s&aring; har du inte cookies aktiverat, eller s&aring; &auml;r Piwik\'s konfigurationsfil redan skapad. %sKontrollera s&aring; att cookies &auml;r aktiverat%s och g&aring; tillbaka %s till f&ouml;rsta sidan av installationen %s.',
	'Provider_WidgetProviders' => 'Operat&ouml;rer',
	'Provider_ColumnProvider' => 'Operat&ouml;r',
	'Provider_SubmenuLocationsProvider' => 'Ursprung och operat&ouml;r',
	'Goals_ColumnConversions' => 'Omvandlingar',
	'Goals_ColumnConversionRate' => 'Omvandlingsfrekvens',
	'Goals_ColumnRevenue' => 'Inkomster',
	'DBStats_DatabaseUsage' => 'Databasanv&auml;ndning',
	'DBStats_MainDescription' => 'Piwik lagrar alla dina analyser i en MySQL-databas. F&ouml;r n&auml;rvarande anv&auml;nder Piwik %s.',
	'DBStats_Table' => 'Tabell',
	'DBStats_RowNumber' => 'Antal rader',
	'DBStats_DataSize' => 'Datam&auml;ngd',
	'DBStats_IndexSize' => 'Indexstorlek',
	'DBStats_TotalSize' => 'Total storlek',
	'TranslationsAdmin_MenuTranslations' => '&ouml;vers&auml;ttningar',
	'TranslationsAdmin_MenuLanguages' => 'Spr&aring;k',
	'TranslationsAdmin_Plugin' => 'Till&auml;gg',
	'TranslationsAdmin_Definition' => 'Definition',
	'TranslationsAdmin_DefaultString' => 'Standardstr&auml;ng (Engelska)',
	'TranslationsAdmin_TranslationString' => '&ouml;vers&auml;ttningsstr&auml;ng (nuvarande spr&aring;k: %s)',
	'TranslationsAdmin_Translations' => '&ouml;vers&auml;ttningar',
	'TranslationsAdmin_FixPermissions' => 'Var v&auml;nlig att r&auml;tta till filsystemets r&auml;ttigheter',
	'TranslationsAdmin_AvailableLanguages' => 'Tillg&auml;ngliga spr&aring;k',
	'TranslationsAdmin_AddLanguage' => 'L&auml;gg till spr&aring;k',
	'TranslationsAdmin_LanguageCode' => 'Spr&aring;kkod',
	'TranslationsAdmin_Export' => 'Exportera spr&aring;k',
	'TranslationsAdmin_Import' => 'Importera spr&aring;k',
);
